## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150,
  eval = TRUE
)

## ----include=FALSE------------------------------------------------------------
library(metalite.ae)

## ----eval = FALSE-------------------------------------------------------------
# adsl <- forestly::forestly_adsl
# adae <- forestly::forestly_adae
# 
# adsl$TRT01A <- factor(
#   adsl$TRT01A,
#   levels = c("Xanomeline Low Dose", "Placebo"),
#   labels = c("Low Dose", "Placebo")
# )
# adae$TRTA <- factor(
#   adae$TRTA,
#   levels = c("Xanomeline Low Dose", "Placebo"),
#   labels = c("Low Dose", "Placebo")
# )
# 
# analysis_plan <- metalite::plan(
#   analysis = "ae_summary",
#   population = "apat",
#   observation = "wk12",
#   parameter = "any;rel;ser"
# )
# 
# meta <- metalite::meta_adam(observation = adae, population = adsl) |>
#   metalite::define_plan(analysis_plan) |>
#   metalite::define_population(
#     name = "apat",
#     var = c(
#       "USUBJID", "SAFFL", "TRT01A", "TRTDUR",
#       "SITEID", "SEX", "RACE", "AGE"
#     ),
#     group = "TRT01A",
#     subset = SAFFL == "Y",
#     label = "All Participants as Treated"
#   ) |>
#   metalite::define_observation(
#     name = "wk12",
#     var = c(
#       "USUBJID", "SAFFL", "TRTA", "AEDECOD", "AEBODSYS", "AEREL",
#       "AESER", "AEOUT", "AEACN", "AESDTH", "ASTDT", "AENDT"
#     ),
#     group = "TRTA",
#     subset = SAFFL == "Y",
#     label = "Weeks 0 to 12"
#   ) |>
#   metalite::define_parameter(
#     name = "any",
#     term1 = "",
#     term2 = "",
#     var = "AEDECOD",
#     soc = "AEBODSYS",
#     label = "All AEs"
#   ) |>
#   metalite::define_parameter(
#     name = "rel",
#     term1 = "Drug-Related",
#     term2 = "",
#     subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
#     var = "AEDECOD",
#     soc = "AEBODSYS",
#     label = "Drug-related AEs"
#   ) |>
#   metalite::define_parameter(
#     name = "ser",
#     term1 = "Serious",
#     term2 = "",
#     subset = AESER == "Y",
#     var = "AEDECOD",
#     soc = "AEBODSYS",
#     label = "Serious AEs"
#   ) |>
#   metalite::define_analysis(
#     name = "ae_summary",
#     title = "Adverse Event Summary"
#   ) |>
#   metalite::meta_build()

## ----eval = FALSE-------------------------------------------------------------
# x <- meta |> # Example AE data created using metalite
#   prepare_ae_summary(
#     population = "apat", # Select population by keywords
#     observation = "wk12", # Select observation by keywords
#     parameter = "any;rel;ser" # Select AE terms by keywords
#   )

## ----eval=FALSE---------------------------------------------------------------
# x <- x |> format_ae_summary()

## ----eval=FALSE---------------------------------------------------------------
# rtf_dir <- if (dir.exists("vignettes/rtf")) "vignettes/rtf" else "rtf"
# rtf_file <- file.path(rtf_dir, "ae0summary1.rtf")
# 
# x |>
#   tlf_ae_summary(
#     source = "Source:  [CDISCpilot: adam-adsl; adae]", # Define data source
#     analysis = "ae_summary", # Provide analysis type defined in meta$analysis
#     path_outtable = rtf_file # Define output
#   )

## ----download-rtf, results="asis", echo=FALSE---------------------------------
cat(
  "Generated RTF file: ae0summary1.rtf"
)

